==> mingw-w64-i686-python-contourpy-1.1.0-1-any.pkg.tar.zst: mingw32/lib/python3.10/site-packages/contourpy/util/_build_config.py <==
# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.
    """
    return dict(
        # Python settings
        python_version="3.10",
        python_install_dir=r"D:/a/msys64/mingw32/lib/python3.10/site-packages/",
        python_path=r"D:/a/msys64/mingw32/bin/python.exe",

        # Package versions
        contourpy_version="1.1.0",
        meson_version="1.1.1",
        mesonpy_version="0.13.1",
        pybind11_version="2.10.4",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"C:/M/B/src/python-build-MINGW32/.mesonpy-2imz8odx/build/lib/contourpy/util",
        source_dir=r"C:/M/B/src/python-build-MINGW32/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/M/B/src/python-build-MINGW32/.mesonpy-2imz8odx/build/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="False",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="gcc",
        compiler_version="13.1.0",
        linker_id="ld.bfd",
        compile_command="g++",

        # Host machine
        host_cpu="x86",
        host_cpu_family="x86",
        host_cpu_endian="little",
        host_cpu_system="windows",

        # Build machine, same as host machine if not a cross_build
        build_cpu="x86",
        build_cpu_family="x86",
        build_cpu_endian="little",
        build_cpu_system="windows",
    )

==> mingw-w64-i686-python-contourpy-1.1.1-1-any.pkg.tar.zst: mingw32/lib/python3.11/site-packages/contourpy/util/_build_config.py <==
# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.
    """
    return dict(
        # Python settings
        python_version="3.11",
        python_install_dir=r"D:/a/msys64/mingw32/lib/python3.11/site-packages/",
        python_path=r"D:/a/msys64/mingw32/bin/python.exe",

        # Package versions
        contourpy_version="1.1.1",
        meson_version="1.2.1",
        mesonpy_version="0.14.0",
        pybind11_version="2.11.1",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"C:/M/B/src/python-build-MINGW32/.mesonpy-wsve_ntv/lib/contourpy/util",
        source_dir=r"C:/M/B/src/python-build-MINGW32/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/M/B/src/python-build-MINGW32/.mesonpy-wsve_ntv/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="False",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="gcc",
        compiler_version="13.2.0",
        linker_id="ld.bfd",
        compile_command="g++",

        # Host machine
        host_cpu="x86",
        host_cpu_family="x86",
        host_cpu_endian="little",
        host_cpu_system="windows",

        # Build machine, same as host machine if not a cross_build
        build_cpu="x86",
        build_cpu_family="x86",
        build_cpu_endian="little",
        build_cpu_system="windows",
    )
